==> ideaIC-171.2014.21-sources.jar: com/intellij/ui/EditorComboBoxRenderer.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ui;

import javax.swing.*;
import javax.swing.plaf.basic.BasicComboBoxRenderer;
import java.awt.*;

/**
 * @author max
 */
public class EditorComboBoxRenderer extends BasicComboBoxRenderer {
  private final ComboBoxEditor myEditor;
          
  public EditorComboBoxRenderer(ComboBoxEditor editor) {
    myEditor = editor;
  }

  public Component getListCellRendererComponent(JList list,
                                                Object value,
                                                int index,
                                                boolean isSelected,
                                                boolean cellHasFocus) {
    final Component editorComponent = myEditor.getEditorComponent();
    Font editorFont = editorComponent.getFont();

    final Component component = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
    component.setFont(editorFont);
    component.setSize(editorComponent.getSize());
    return component;
  }
}

==> ideaIC-182.4323.18-sources.jar: com/intellij/ui/EditorComboBoxRenderer.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ui;

import com.intellij.util.ui.UIUtil;

import javax.swing.*;
import javax.swing.plaf.basic.BasicComboBoxRenderer;
import java.awt.*;

/**
 * @author max
 */
public class EditorComboBoxRenderer extends BasicComboBoxRenderer {
  private final ComboBoxEditor myEditor;
          
  public EditorComboBoxRenderer(ComboBoxEditor editor) {
    myEditor = editor;
  }

  public Component getListCellRendererComponent(JList list,
                                                Object value,
                                                int index,
                                                boolean isSelected,
                                                boolean cellHasFocus) {
    final Component editorComponent = myEditor.getEditorComponent();
    Font editorFont = editorComponent.getFont();
    final Component component = super.getListCellRendererComponent(list, UIUtil.htmlInjectionGuard(value), index, isSelected, cellHasFocus);
    component.setFont(editorFont);
    component.setSize(editorComponent.getSize());
    return component;
  }
}
